@@ -4,23 +4,20 @@
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package).
 #'
-#' The data is current to January 2015. Downloaded size is <1 MB.
+#' The data is current to December 2020. Downloaded size is 1.5 MB.
 #'
-#' @format \code{sf} data frame with 480 rows of 5 variables + geometry
+#' @format \code{sf} data frame with 1.769 rows of 2 variables + geometry
 #'
 #' \describe{
-#'   \item{TYP}{Type of water body: 1 = dam, 2 = pond, 3 = lake}
 #'   \item{NAZEV}{Name, with Czech accents}
-#'   \item{NAZEV_ASCII}{Name, without Czech accents}
 #'   \item{VYSKA}{water level, meters above sea level}
-#'   \item{Major}{Boolean indicating major water bodies}
 #' }
 #'
-#' @source © ArcČR, ARCDATA PRAHA, ZÚ, ČSÚ, 2016 \url{https://www.arcdata.cz/produkty/geograficka-data/arccr-4-0}
+#' @source Mapový podklad – Data200, 2021 © Český úřad zeměměřický a katastrální. \url{https://www.cuzk.cz}
 #'
 #' @export
 
 plochy <- function() {
-  result <- downloader("Plochy.rds")
+  result <- .downloader("Plochy-D200-2021-07.rds")
   result
 }
