@@ -4,9 +4,9 @@
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package).
 #'
-#' The data is current to January 2015. Downloaded size is 1.5 MB.
+#' The data is current to December 2020. Downloaded size is 6 MB.
 #'
-#' @format \code{sf} data frame with 18.979 rows of 4 variables + geometry:
+#' @format \code{sf} data frame with 59.594 rows of 3 variables + geometry:
 #'
 #' \describe{
 #'   \item{TRIDA}{Class of the road: highway = dálnice, speedway = rychlostní silnice, 1st class road = silnice I. třídy, 2nd class road = silnice II. třídy, 3rd class road = silnice III. třídy, other road = neevidovaná silnice}
@@ -14,11 +14,11 @@
 #'   \item{MEZINARODNI_OZNACENI}{International road code}
 #' }
 #'
-#' @source © ArcČR, ARCDATA PRAHA, ZÚ, ČSÚ, 2016 \url{https://www.arcdata.cz/produkty/geograficka-data/arccr-4-0}
+#' @source Mapový podklad – Data200, 2021 © Český úřad zeměměřický a katastrální. \url{https://www.cuzk.cz}
 #'
 #' @export
 
 silnice <- function() {
-  result <- downloader("Silnice.rds")
+  result <- .downloader("Silnice-D200-2021-07.rds")
   result
 }
